<?php
/** @noinspection PhpDeprecationInspection */
declare (strict_types = 1);

namespace USKit\Base\ViewModels;

use Infomaker\Everyware\Base\Menus;
use USKit\Base\Interfaces\ViewModel;
use Infomaker\Everyware\Support\GenericPropertyObject;

class Page implements ViewModel
{
    /**
     * Contains the article to fetch data from
     *
     * @var GenericPropertyObject
     */
    protected $viewData;

    /**
     * ViewModel constructor.
     *
     * @param GenericPropertyObject $object
     */
    public function __construct(GenericPropertyObject $object)
    {
        $this->viewData = $object;
        $this->viewData->fill([
            'menu' => $this->getMenuItems('main-menu'),
        ]);
    }

    /**
     * Retrieve data to be used in the View
     *
     * @return array
     */
    public function getViewData(): array
    {
        return $this->viewData->toArray();
    }

    public function setViewData($property, $data)
    {
        return $this->viewData->fill([$property => $data]);
    }

    protected function getMenuItems(string $menuName)
    {
        $menu = Menus::getFromLocation($menuName);
        return $menu ? $menu->items(true) : [];
    }
}
